diff --git a/saiadmin-artd/src/views/plugin/dice/config/index/index.vue b/saiadmin-artd/src/views/plugin/dice/config/index/index.vue
index 0117d1c..2a13ac4 100644
--- a/saiadmin-artd/src/views/plugin/dice/config/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/config/index/index.vue
@@ -8,23 +8,23 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -50,11 +50,11 @@
type="secondary"
@click="showDialog('edit', row)"
/>
-
-
-
-
-
+
+
+
+
+
@@ -108,12 +108,19 @@
core: {
apiFn: api.list,
columnsFactory: () => [
- { type: 'selection' },
- { prop: 'group', label: '分组', minWidth: 140 },
- { prop: 'title', label: '标题', minWidth: 160 },
- { prop: 'name', label: '配置名称' },
- { prop: 'value', label: '值', minWidth: 240 },
- { prop: 'operation', label: '操作', width: 100, fixed: 'right', useSlot: true }
+ // { type: 'selection' },
+ { prop: 'group', label: '分组', minWidth: 140, align: 'center' },
+ { prop: 'title', label: '标题', minWidth: 160, align: 'center' },
+ { prop: 'name', label: '配置名称', align: 'center' },
+ { prop: 'value', label: '值', minWidth: 240, align: 'center' },
+ {
+ prop: 'operation',
+ label: '操作',
+ width: 60,
+ align: 'center',
+ fixed: 'right',
+ useSlot: true
+ }
]
}
})
@@ -124,9 +131,9 @@
dialogVisible,
dialogData,
showDialog,
- deleteRow,
- deleteSelectedRows,
- handleSelectionChange,
- selectedRows
+ // deleteRow,
+ // deleteSelectedRows,
+ handleSelectionChange
+ // selectedRows
} = useSaiAdmin()
diff --git a/saiadmin-artd/src/views/plugin/dice/config/index/modules/edit-dialog.vue b/saiadmin-artd/src/views/plugin/dice/config/index/modules/edit-dialog.vue
index 7150457..31c58b4 100644
--- a/saiadmin-artd/src/views/plugin/dice/config/index/modules/edit-dialog.vue
+++ b/saiadmin-artd/src/views/plugin/dice/config/index/modules/edit-dialog.vue
@@ -9,13 +9,21 @@
>
-
+
-
+
diff --git a/saiadmin-artd/src/views/plugin/dice/lottery_config/index/index.vue b/saiadmin-artd/src/views/plugin/dice/lottery_config/index/index.vue
index 6c4ddb3..e8dc71e 100644
--- a/saiadmin-artd/src/views/plugin/dice/lottery_config/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/lottery_config/index/index.vue
@@ -7,29 +7,29 @@
-
-
-
-
-
- 新增
-
-
-
-
-
- 删除
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -54,11 +54,11 @@
type="secondary"
@click="showDialog('edit', row)"
/>
-
+
+
+
+
+
@@ -121,16 +121,52 @@
core: {
apiFn: api.list,
columnsFactory: () => [
- { type: 'selection' },
- { prop: 'name', label: '名称' },
- { prop: 'type', label: '奖池类型', width: 100, formatter: typeFormatter },
- { prop: 'safety_line', label: '安全线' },
- { prop: 't1_wight', label: 'T1池权重', width: 100, formatter: weightFormatter('t1_wight') },
- { prop: 't2_wight', label: 'T2池权重', width: 100, formatter: weightFormatter('t2_wight') },
- { prop: 't3_wight', label: 'T3池权重', width: 100, formatter: weightFormatter('t3_wight') },
- { prop: 't4_wight', label: 'T4池权重', width: 100, formatter: weightFormatter('t4_wight') },
- { prop: 't5_wight', label: 'T5池权重', width: 100, formatter: weightFormatter('t5_wight') },
- { prop: 'operation', label: '操作', width: 100, fixed: 'right', useSlot: true }
+ { prop: 'name', label: '名称', align: 'center' },
+ { prop: 'type', label: '奖池类型', width: 100, align: 'center', formatter: typeFormatter },
+ { prop: 'safety_line', label: '安全线', align: 'center' },
+ {
+ prop: 't1_wight',
+ label: 'T1池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t1_wight')
+ },
+ {
+ prop: 't2_wight',
+ label: 'T2池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t2_wight')
+ },
+ {
+ prop: 't3_wight',
+ label: 'T3池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t3_wight')
+ },
+ {
+ prop: 't4_wight',
+ label: 'T4池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t4_wight')
+ },
+ {
+ prop: 't5_wight',
+ label: 'T5池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t5_wight')
+ },
+ {
+ prop: 'operation',
+ label: '操作',
+ width: 60,
+ align: 'center',
+ fixed: 'right',
+ useSlot: true
+ }
]
}
})
@@ -141,9 +177,9 @@
dialogVisible,
dialogData,
showDialog,
- deleteRow,
- deleteSelectedRows,
- handleSelectionChange,
- selectedRows
+ // deleteRow,
+ // deleteSelectedRows,
+ handleSelectionChange
+ // selectedRows
} = useSaiAdmin()
diff --git a/saiadmin-artd/src/views/plugin/dice/lottery_config/index/modules/edit-dialog.vue b/saiadmin-artd/src/views/plugin/dice/lottery_config/index/modules/edit-dialog.vue
index fdba95a..5d18637 100644
--- a/saiadmin-artd/src/views/plugin/dice/lottery_config/index/modules/edit-dialog.vue
+++ b/saiadmin-artd/src/views/plugin/dice/lottery_config/index/modules/edit-dialog.vue
@@ -9,7 +9,11 @@
>
-
+
diff --git a/saiadmin-artd/src/views/plugin/dice/play_record/index/index.vue b/saiadmin-artd/src/views/plugin/dice/play_record/index/index.vue
index 4e2a0fb..63e8104 100644
--- a/saiadmin-artd/src/views/plugin/dice/play_record/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/play_record/index/index.vue
@@ -7,29 +7,29 @@
-
-
-
-
-
- 新增
-
-
-
-
-
- 删除
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -82,11 +82,11 @@
type="secondary"
@click="showDialog('edit', row)"
/>
-
+
+
+
+
+
@@ -168,7 +168,7 @@
core: {
apiFn: api.list,
columnsFactory: () => [
- { type: 'selection' },
+ // { type: 'selection' },
{ prop: 'id', label: 'ID', width: 80 },
{
prop: 'player_id',
@@ -206,9 +206,9 @@
dialogVisible,
dialogData,
showDialog,
- deleteRow,
- deleteSelectedRows,
- handleSelectionChange,
- selectedRows
+ // deleteRow,
+ // deleteSelectedRows,
+ handleSelectionChange
+ // selectedRows
} = useSaiAdmin()
diff --git a/saiadmin-artd/src/views/plugin/dice/player/index/index.vue b/saiadmin-artd/src/views/plugin/dice/player/index/index.vue
index af17b2d..3238325 100644
--- a/saiadmin-artd/src/views/plugin/dice/player/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/player/index/index.vue
@@ -158,23 +158,78 @@
apiFn: api.list,
columnsFactory: () => [
{ type: 'selection' },
- { prop: 'username', label: '用户名' },
- { prop: 'phone', label: '手机号' },
- { prop: 'name', label: '昵称' },
- { prop: 'status', label: '状态', width: 88, useSlot: true },
- { prop: 'coin', label: '平台币', width: 100, useSlot: true },
- { prop: 'is_up', label: '倍率', width: 80, formatter: isUpFormatter },
- { prop: 't1_wight', label: 'T1池权重', width: 100, formatter: weightFormatter('t1_wight') },
- { prop: 't2_wight', label: 'T2池权重', width: 100, formatter: weightFormatter('t2_wight') },
- { prop: 't3_wight', label: 'T3池权重', width: 100, formatter: weightFormatter('t3_wight') },
- { prop: 't4_wight', label: 'T4池权重', width: 100, formatter: weightFormatter('t4_wight') },
- { prop: 't5_wight', label: 'T5池权重', width: 100, formatter: weightFormatter('t5_wight') },
- { prop: 'total_ticket_count', label: '总抽奖次数' },
- { prop: 'paid_ticket_count', label: '购买抽奖次数' },
- { prop: 'free_ticket_count', label: '赠送抽奖次数' },
- { prop: 'created_at', label: '创建时间' },
- { prop: 'updated_at', label: '更新时间' },
- { prop: 'operation', label: '操作', width: 120, fixed: 'right', useSlot: true }
+ { prop: 'username', label: '用户名', align: 'center' },
+ { prop: 'phone', label: '手机号', align: 'center' },
+ { prop: 'name', label: '昵称', align: 'center' },
+ {
+ prop: 'status',
+ label: '状态',
+ width: 88,
+ align: 'center',
+ useSlot: true
+ },
+ {
+ prop: 'coin',
+ label: '平台币',
+ width: 100,
+ align: 'center',
+ useSlot: true
+ },
+ {
+ prop: 'is_up',
+ label: '倍率',
+ width: 80,
+ align: 'center',
+ formatter: isUpFormatter
+ },
+ {
+ prop: 't1_wight',
+ label: 'T1池权重',
+ width: 80,
+ align: 'center',
+ formatter: weightFormatter('t1_wight')
+ },
+ {
+ prop: 't2_wight',
+ label: 'T2池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t2_wight')
+ },
+ {
+ prop: 't3_wight',
+ label: 'T3池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t3_wight')
+ },
+ {
+ prop: 't4_wight',
+ label: 'T4池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t4_wight')
+ },
+ {
+ prop: 't5_wight',
+ label: 'T5池权重',
+ width: 100,
+ align: 'center',
+ formatter: weightFormatter('t5_wight')
+ },
+ { prop: 'total_ticket_count', label: '总抽奖次数', align: 'center' },
+ { prop: 'paid_ticket_count', label: '购买抽奖次数', align: 'center' },
+ { prop: 'free_ticket_count', label: '赠送抽奖次数', align: 'center' },
+ { prop: 'created_at', label: '创建时间', align: 'center' },
+ { prop: 'updated_at', label: '更新时间', align: 'center' },
+ {
+ prop: 'operation',
+ label: '操作',
+ width: 100,
+ align: 'center',
+ fixed: 'right',
+ useSlot: true
+ }
]
}
})
diff --git a/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/index.vue b/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/index.vue
index 4a15995..c2aeea0 100644
--- a/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/index.vue
@@ -8,23 +8,23 @@
-
-
-
-
- 新增
-
-
-
-
-
- 删除
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -50,11 +50,11 @@
type="secondary"
@click="showDialog('edit', row)"
/>
-
+
+
+
+
+
@@ -77,7 +77,6 @@
import TableSearch from './modules/table-search.vue'
import EditDialog from './modules/edit-dialog.vue'
-
// 搜索表单
const searchForm = ref>({
username: undefined,
@@ -127,16 +126,28 @@
const usernameFormatter = (row: Record) =>
row?.dicePlayer?.username ?? row?.player_id ?? '-'
return [
- { type: 'selection' },
- { prop: 'id', label: 'ID', width: 80 },
- { prop: 'player_id', label: '玩家用户名', formatter: (row: Record) => usernameFormatter(row) },
- { prop: 'use_coins', label: '消耗硬币' },
- { prop: 'total_ticket_count', label: '总抽奖次数' },
- { prop: 'paid_ticket_count', label: '购买抽奖次数' },
- { prop: 'free_ticket_count', label: '赠送抽奖次数' },
- { prop: 'remark', label: '备注', width: 100, showOverflowTooltip: true },
- { prop: 'create_time', label: '创建时间', width: 170 },
- { prop: 'operation', label: '操作', width: 100, fixed: 'right', useSlot: true }
+ // { type: 'selection' },
+ { prop: 'id', label: 'ID', width: 80, align: 'center' },
+ {
+ prop: 'player_id',
+ label: '玩家用户名',
+ align: 'center',
+ formatter: (row: Record) => usernameFormatter(row)
+ },
+ { prop: 'use_coins', label: '消耗硬币', align: 'center' },
+ { prop: 'total_ticket_count', label: '总抽奖次数', align: 'center' },
+ { prop: 'paid_ticket_count', label: '购买抽奖次数', align: 'center' },
+ { prop: 'free_ticket_count', label: '赠送抽奖次数', align: 'center' },
+ { prop: 'remark', label: '备注', width: 100, align: 'center', showOverflowTooltip: true },
+ { prop: 'create_time', label: '创建时间', width: 170, align: 'center' },
+ {
+ prop: 'operation',
+ label: '操作',
+ width: 60,
+ align: 'center',
+ fixed: 'right',
+ useSlot: true
+ }
]
}
}
@@ -148,10 +159,9 @@
dialogVisible,
dialogData,
showDialog,
- deleteRow,
- deleteSelectedRows,
- handleSelectionChange,
- selectedRows
+ // deleteRow,
+ // deleteSelectedRows,
+ handleSelectionChange
+ // selectedRows
} = useSaiAdmin()
-
diff --git a/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/modules/edit-dialog.vue b/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/modules/edit-dialog.vue
index bf03805..c5d181f 100644
--- a/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/modules/edit-dialog.vue
+++ b/saiadmin-artd/src/views/plugin/dice/player_ticket_record/index/modules/edit-dialog.vue
@@ -26,7 +26,12 @@
-
+
@@ -42,6 +48,7 @@
placeholder="请输入赠送抽奖次数"
:min="0"
@change="onTicketCountChange"
+ :disabled="dialogType === 'edit'"
/>
@@ -60,6 +67,8 @@
placeholder="请输入备注(必填)"
maxlength="500"
show-word-limit
+ style="width: 100%"
+ :disabled="dialogType === 'edit'"
/>
diff --git a/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/index.vue b/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/index.vue
index 97d31d6..5e313b1 100644
--- a/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/index.vue
@@ -7,29 +7,29 @@
-
-
-
-
-
- 新增
-
-
-
-
-
- 删除
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -60,11 +60,11 @@
type="secondary"
@click="showDialog('edit', row)"
/>
-
+
+
+
+
+
@@ -203,7 +203,7 @@
{
prop: 'operation',
label: '操作',
- width: 100,
+ width: 60,
align: 'center',
fixed: 'right',
useSlot: true
@@ -218,10 +218,10 @@
dialogVisible,
dialogData,
showDialog,
- deleteRow,
- deleteSelectedRows,
- handleSelectionChange,
- selectedRows
+ // deleteRow,
+ // deleteSelectedRows,
+ handleSelectionChange
+ // selectedRows
} = useSaiAdmin()
diff --git a/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/modules/edit-dialog.vue b/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/modules/edit-dialog.vue
index 1983cce..9900b39 100644
--- a/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/modules/edit-dialog.vue
+++ b/saiadmin-artd/src/views/plugin/dice/player_wallet_record/index/modules/edit-dialog.vue
@@ -27,7 +27,13 @@
-
+
@@ -42,6 +48,7 @@
:precision="2"
style="width: 100%"
@change="onCoinChange"
+ :disabled="dialogType === 'edit'"
/>
@@ -70,6 +77,7 @@
placeholder="选填"
maxlength="500"
show-word-limit
+ :disabled="dialogType === 'edit'"
/>
diff --git a/saiadmin-artd/src/views/plugin/dice/reward_config/index/modules/edit-dialog.vue b/saiadmin-artd/src/views/plugin/dice/reward_config/index/modules/edit-dialog.vue
index d0a6eb6..d33abe4 100644
--- a/saiadmin-artd/src/views/plugin/dice/reward_config/index/modules/edit-dialog.vue
+++ b/saiadmin-artd/src/views/plugin/dice/reward_config/index/modules/edit-dialog.vue
@@ -9,7 +9,11 @@
>
-
+
@@ -23,6 +27,7 @@
placeholder="请选择所属档位"
clearable
style="width: 100%"
+ :disabled="dialogType === 'edit'"
>
diff --git a/saiadmin-artd/src/views/plugin/dice/reward_config/index/index.vue b/saiadmin-artd/src/views/plugin/dice/reward_config/index/index.vue
index 0a6995e..0846882 100644
--- a/saiadmin-artd/src/views/plugin/dice/reward_config/index/index.vue
+++ b/saiadmin-artd/src/views/plugin/dice/reward_config/index/index.vue
@@ -8,27 +8,27 @@
-
-
-
-
- 新增
-
-
-
-
-
- 删除
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -54,11 +54,11 @@
type="secondary"
@click="showDialog('edit', row)"
/>
-
+
+
+
+
+
@@ -116,14 +116,21 @@
apiFn: api.list,
apiParams: { limit: 100 },
columnsFactory: () => [
- { type: 'selection' },
- { prop: 'id', label: 'ID(索引)', width: 80 },
- { prop: 'grid_number', label: '色子点数' },
- { prop: 'ui_text', label: '前端显示文本' },
- { prop: 'real_ev', label: '真实资金结算' },
- { prop: 'tier', label: '所属档位', sortable: true },
- // { prop: 'create_time', label: '创建时间', sortable: true },
- { prop: 'operation', label: '操作', width: 100, fixed: 'right', useSlot: true }
+ // { type: 'selection' },
+ { prop: 'id', label: 'ID(索引)', width: 80, align: 'center' },
+ { prop: 'grid_number', label: '色子点数', align: 'center' },
+ { prop: 'ui_text', label: '前端显示文本', align: 'center' },
+ { prop: 'real_ev', label: '真实资金结算', align: 'center' },
+ { prop: 'tier', label: '所属档位', sortable: true, align: 'center' },
+ // { prop: 'create_time', label: '创建时间', sortable: true, align: 'center' },
+ {
+ prop: 'operation',
+ label: '操作',
+ width: 60,
+ align: 'center',
+ fixed: 'right',
+ useSlot: true
+ }
]
}
})
@@ -134,9 +141,9 @@
dialogVisible,
dialogData,
showDialog,
- deleteRow,
- deleteSelectedRows,
- handleSelectionChange,
- selectedRows
+ // deleteRow,
+ // deleteSelectedRows,
+ handleSelectionChange
+ // selectedRows
} = useSaiAdmin()